@@ -1215,28 +1215,25 @@ empathy_text_iter_backward_search (const GtkTextIter   *iter,
 	return retval;
 }
 
-static gboolean
-window_get_is_on_current_workspace (GtkWindow *window)
-{
-	GdkWindow *gdk_window;
-
-	gdk_window = GTK_WIDGET (window)->window;
-	if (gdk_window) {
-		return !(gdk_window_get_state (gdk_window) &
-			 GDK_WINDOW_STATE_ICONIFIED);
-	} else {
-		return FALSE;
-	}
-}
-
-/* Checks if the window is visible as in visible on the current workspace. */
 gboolean
 empathy_window_get_is_visible (GtkWindow *window)
 {
+	GdkWindowState  state;
+	GdkWindow      *gdk_window;
+
 	g_return_val_if_fail (GTK_IS_WINDOW (window), FALSE);
 
-	return GTK_WIDGET_VISIBLE (GTK_WIDGET (window)) &&
-	       window_get_is_on_current_workspace (window);
+	gdk_window = GTK_WIDGET (window)->window;
+	if (!gdk_window) {
+		return FALSE;
+	}
+
+	state = gdk_window_get_state (gdk_window);
+	if (state & (GDK_WINDOW_STATE_WITHDRAWN | GDK_WINDOW_STATE_ICONIFIED)) {
+		return FALSE;
+	}
+
+	return TRUE;
 }
 
 void 
@@ -1265,38 +1262,29 @@ empathy_window_iconify (GtkWindow *window, GtkStatusIcon *status_icon)
 
 	gtk_window_set_skip_taskbar_hint (window, TRUE);
 	gtk_window_iconify (window);
-
 }
 
 /* Takes care of moving the window to the current workspace. */
 void
 empathy_window_present (GtkWindow *window,
-		       gboolean   steal_focus)
+			gboolean   steal_focus)
 {
-	gboolean on_current;
-	guint32  timestamp;
+	guint32 timestamp;
 
-	g_return_if_fail (window != NULL);
+	g_return_if_fail (GTK_IS_WINDOW (window));
 
 	/* There are three cases: hidden, visible, visible on another
 	 * workspace.
 	 */
 
-	on_current = window_get_is_on_current_workspace (window);
-
-	if ( GTK_WIDGET_VISIBLE (GTK_WIDGET (window)) && !on_current) {
+	if (!empathy_window_get_is_visible (window)) {
 		/* Hide it so present brings it to the current workspace. */
 		gtk_widget_hide (GTK_WIDGET (window));
 	}
 
-	gtk_window_set_skip_taskbar_hint (window, FALSE);
-
 	timestamp = gtk_get_current_event_time ();
-	if (steal_focus && timestamp != GDK_CURRENT_TIME) {
-		gtk_window_present_with_time (window, timestamp);
-	} else {
-		gtk_window_present (window);
-	}
+	gtk_window_set_skip_taskbar_hint (window, FALSE);
+	gtk_window_present_with_time (window, timestamp);
 }
 
 GtkWindow *
@@ -1388,3 +1376,51 @@ empathy_toggle_button_set_state_quietly (GtkWidget *widget,
 	g_signal_handlers_unblock_by_func (widget, callback, user_data);
 }
 
+GtkTextTag *
+empathy_text_buffer_tag_set (GtkTextBuffer *buffer,
+			     const gchar   *tag_name,
+			     const gchar   *first_property_name,
+			     ...)
+{
+	GtkTextTagTable *table;
+	GtkTextTag      *tag;
+
+	g_return_val_if_fail (GTK_IS_TEXT_BUFFER (buffer), NULL);
+	g_return_val_if_fail (tag_name != NULL, NULL);
+
+	table = gtk_text_buffer_get_tag_table (buffer);
+	tag = gtk_text_tag_table_lookup (table, tag_name);
+
+	if (!tag) {
+		tag = gtk_text_tag_new (tag_name);
+		gtk_text_tag_table_add (table, tag);
+		g_object_unref (tag);
+	} else {
+		/* Clear the old values so that we don't affect the new theme. */
+		g_object_set (tag,
+			      "background-set", FALSE,
+			      "foreground-set", FALSE,
+			      "invisible-set", FALSE,
+			      "justification-set", FALSE,
+			      "paragraph-background-set", FALSE,
+			      "pixels-above-lines-set", FALSE,
+			      "pixels-below-lines-set", FALSE,
+			      "rise-set", FALSE,
+			      "scale-set", FALSE,
+			      "size-set", FALSE,
+			      "style-set", FALSE,
+			      "weight-set", FALSE,
+			      NULL);
+	}
+
+	if (first_property_name) {
+		va_list list;
+
+		va_start (list, first_property_name);
+		g_object_set_valist (G_OBJECT (tag), first_property_name, list);
+		va_end (list);
+	}
+
+	return tag;
+}
+
