@@ -29,6 +29,7 @@
 #include <libtelepathy/tp-conn.h>
 #include <libtelepathy/tp-chan.h>
 #include <libtelepathy/tp-chan-type-contact-list-gen.h>
+#include <telepathy-glib/util.h>
 
 #include "empathy-tp-contact-list.h"
 #include "empathy-contact-list.h"
@@ -169,7 +170,7 @@ tp_contact_list_find_group (EmpathyTpContactList *list,
 	GList                    *l;
 
 	for (l = priv->groups; l; l = l->next) {
-		if (strcmp (group, empathy_tp_group_get_name (l->data)) == 0) {
+		if (!tp_strdiff (group, empathy_tp_group_get_name (l->data))) {
 			return l->data;
 		}
 	}
@@ -180,22 +181,16 @@ static TpContactListType
 tp_contact_list_get_type (EmpathyTpContactList *list,
 			  EmpathyTpGroup       *group)
 {
-	EmpathyTpContactListPriv *priv;
-	TpContactListType         list_type;
-	const gchar              *name;
-
-	priv = GET_PRIV (list);
+	const gchar *name;
 
 	name = empathy_tp_group_get_name (group);
-	if (strcmp (name, "subscribe") == 0) {
-		list_type = TP_CONTACT_LIST_TYPE_SUBSCRIBE;
-	} else if (strcmp (name, "publish") == 0) {
-		list_type = TP_CONTACT_LIST_TYPE_PUBLISH;
-	} else {
-		list_type = TP_CONTACT_LIST_TYPE_UNKNOWN;
+	if (!tp_strdiff (name, "subscribe")) {
+		return TP_CONTACT_LIST_TYPE_SUBSCRIBE;
+	} else if (!tp_strdiff (name, "publish")) {
+		return TP_CONTACT_LIST_TYPE_PUBLISH;
 	}
 
-	return list_type;
+	return TP_CONTACT_LIST_TYPE_UNKNOWN;
 }
 
 static void
@@ -980,6 +975,33 @@ tp_contact_list_rename_group (EmpathyContactList *list,
 	g_list_free (members);
 }
 
+static void
+tp_contact_list_remove_group (EmpathyContactList *list,
+			      const gchar *group)
+{
+	EmpathyTpGroup *tp_group;
+	GList	       *members;
+
+	g_return_if_fail (EMPATHY_IS_TP_CONTACT_LIST (list));
+
+	tp_group = tp_contact_list_find_group (EMPATHY_TP_CONTACT_LIST (list),
+					       group);
+	
+	if (!tp_group) {
+		return;
+	}
+
+	empathy_debug (DEBUG_DOMAIN, "remove group %s", group);
+
+	/* Remove all members of the group */
+	members = empathy_tp_group_get_members (tp_group);
+	empathy_tp_group_remove_members (tp_group, members, "");
+	empathy_tp_group_close (tp_group);
+
+	g_list_foreach (members, (GFunc) g_object_unref, NULL);
+	g_list_free (members);
+}
+
 static void
 tp_contact_list_iface_init (EmpathyContactListIface *iface)
 {
@@ -992,5 +1014,6 @@ tp_contact_list_iface_init (EmpathyContactListIface *iface)
 	iface->add_to_group      = tp_contact_list_add_to_group;
 	iface->remove_from_group = tp_contact_list_remove_from_group;
 	iface->rename_group      = tp_contact_list_rename_group;
+	iface->remove_group	 = tp_contact_list_remove_group;
 }
 
